@@ -44,13 +44,6 @@
 //!
 //! # fn main() { foo().unwrap() }
 //! ```
-#[macro_use]
-extern crate lazy_static;
-extern crate regex;
-extern crate uuid;
-
-#[cfg(feature = "with_serde")]
-extern crate serde;
 
 use regex::Regex;
 use std::error;
@@ -58,20 +51,28 @@ use std::fmt;
 use std::str;
 use uuid::Uuid;
 
-lazy_static! {
+lazy_static::lazy_static! {
     static ref DEBUG_ID_RE: Regex = Regex::new(
         r"(?ix)
         ^
-            ([0-9a-f]{8}-?
-             [0-9a-f]{4}-?
-             [0-9a-f]{4}-?
-             [0-9a-f]{4}-?
-             [0-9a-f]{12})
+            (?P<uuid>
+                [0-9a-f]{8}-?
+                [0-9a-f]{4}-?
+                [0-9a-f]{4}-?
+                [0-9a-f]{4}-?
+                [0-9a-f]{12}
+            )
             -?
-            ([0-9a-f]{1,8})?
+            (?P<appendix>
+                [0-9a-f]{1,8}
+            )?
+            ( # ignored tail
+                (?:-?[0-9a-f]){1,24}
+            )?
         $
     "
-    ).unwrap();
+    )
+    .unwrap();
 }
 
 /// Indicates a parsing error
@@ -85,7 +86,7 @@ impl error::Error for ParseDebugIdError {
 }
 
 impl fmt::Display for ParseDebugIdError {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         use std::error::Error;
         write!(f, "{}", self.description())
     }
@@ -173,13 +174,13 @@ impl DebugId {
 
     /// Returns a wrapper which when formatted via `fmt::Display` will format a
     /// a breakpad identifier.
-    pub fn breakpad(&self) -> BreakpadFormat {
+    pub fn breakpad(&self) -> BreakpadFormat<'_> {
         BreakpadFormat { inner: self }
     }
 }
 
 impl fmt::Debug for DebugId {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         f.debug_struct("DebugId")
             .field("uuid", &self.uuid().to_hyphenated_ref().to_string())
             .field("appendix", &self.appendix())
@@ -188,7 +189,7 @@ impl fmt::Debug for DebugId {
 }
 
 impl fmt::Display for DebugId {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         self.uuid.fmt(f)?;
         if self.appendix > 0 {
             write!(f, "-{:x}", { self.appendix })?;
@@ -203,13 +204,13 @@ impl str::FromStr for DebugId {
     fn from_str(string: &str) -> Result<DebugId, ParseDebugIdError> {
         let captures = DEBUG_ID_RE.captures(string).ok_or(ParseDebugIdError)?;
         let uuid = captures
-            .get(1)
+            .name("uuid")
             .unwrap()
             .as_str()
             .parse()
             .map_err(|_| ParseDebugIdError)?;
         let appendix = captures
-            .get(2)
+            .name("appendix")
             .map_or(Ok(0), |s| u32::from_str_radix(s.as_str(), 16))
             .map_err(|_| ParseDebugIdError)?;
         Ok(DebugId::from_parts(uuid, appendix))
@@ -288,7 +289,7 @@ pub struct BreakpadFormat<'a> {
 }
 
 impl<'a> fmt::Display for BreakpadFormat<'a> {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(
             f,
             "{:X}{:x}",
